@@ -1,6 +1,7 @@
 from flask_admin.contrib import sqla
 from hiddifypanel.panel.database import db
-from hiddifypanel.models import  User,Domain,DomainType,StrConfig,ConfigEnum,hconfig
+import datetime
+from hiddifypanel.models import  *
 from flask import Markup,g
 from wtforms.validators import Regexp,ValidationError
 import re,uuid
@@ -9,20 +10,20 @@ from .adminlte import AdminLTEModelView
 # from gettext import gettext as _
 from flask_babelex import gettext as __
 from flask_babelex import lazy_gettext as _
-from hiddifypanel.panel import hiddify
+from hiddifypanel.panel import hiddify,custom_widgets
 from hiddifypanel.panel.hiddify import flash
 from wtforms.fields import StringField
 from flask_bootstrap import SwitchField
 class UserAdmin(AdminLTEModelView):
     
     list_template = 'model/user_list.html'    
-    # form_excluded_columns=['last_reset_time']
+    form_excluded_columns=['monthly']
     # edit_modal=True
     # create_modal=True
     # column_display_pk = True
     # can_export = True
     # form_overrides = dict(monthly=SwitchField)
-    # form_overrides = dict(expiry_time=StringField)
+    form_overrides = dict(expiry_time=custom_widgets.DaysLeftField,last_reset_time=custom_widgets.LastResetField)
     # form_widget_args={
     # 'expiry_time':{'class':'datepicker'}    
     # }
@@ -46,10 +47,12 @@ class UserAdmin(AdminLTEModelView):
         "UserLinks":_("user.user_links"),
         "usage_limit_GB":_("user.usage_limit_GB"),
         "monthly":_("Reset every month"),
+        "mode":_("Mode"),
         "current_usage_GB":_("user.current_usage_GB"),
         "expiry_time":_("user.expiry_time"),
         # "last_reset_time":_("user.last_reset_time"),
         "uuid":_("user.UUID"),
+        "comment":_("Note"),
      }
     column_searchable_list=[("uuid"),"name"]
     def search_placeholder(self):
@@ -61,14 +64,16 @@ class UserAdmin(AdminLTEModelView):
         # name=_'just for remembering',
         # usage_limit_GB="in GB",
         # current_usage_GB="in GB"
+        comment=_("Add some text that is only visible to you."),
+        mode=_("Define the user mode. Should the usage reset every month?"),
         last_reset_time=_("If monthly is enabled, the usage will be reset after 30 days from this date.")
     )
-    column_editable_list=["usage_limit_GB","current_usage_GB","expiry_time"]
+    # column_editable_list=["usage_limit_GB","current_usage_GB","expiry_time"]
     # form_extra_fields={
     #     'uuid': {'label_name':"D"}
         
     #     }
-    column_list = ["name","UserLinks","current_usage_GB","usage_limit_GB",'monthly',"expiry_time","uuid",]
+    column_list = ["name","UserLinks","current_usage_GB",'mode',"expiry_time","comment","uuid"]
     # can_edit = False
     # def on_model_change(self, form, model, is_created):
     #     model.password = generate_password_hash(model.password)
@@ -76,24 +81,52 @@ class UserAdmin(AdminLTEModelView):
     
     def _name_formatter(view, context, model, name):
         proxy_path=hconfig(ConfigEnum.proxy_path)
-        d=Domain.query.filter(Domain.mode!=DomainType.fake).first()
+        if hconfig(ConfigEnum.is_parent):
+            d=ParentDomain.query.first()
+        else:
+            d=Domain.query.filter(Domain.mode!=DomainType.fake).first()
         if d:
             link=f"<a target='_blank' href='https://{d.domain}/{proxy_path}/{model.uuid}/new'><i class='fa-solid fa-arrow-up-right-from-square'></i> {model.name}</a>"
             return Markup(link)
         else:
             return model.name
     def _ul_formatter(view, context, model, name):
-        
-        return Markup(" ".join([hiddify.get_user_link(model.uuid,d,'new') for d in Domain.query.filter(Domain.mode!=DomainType.fake).all()]))
+        if hconfig(ConfigEnum.is_parent):
+            domains=ParentDomain.query.all()
+        else:    
+            domains=Domain.query.filter(Domain.mode!=DomainType.fake).all()
+        return Markup(" ".join([hiddify.get_user_link(model.uuid,d,'new') for d in domains]))
+    
     def _uuid_formatter(view, context, model, name):
         return Markup(f"<span>{model.uuid}</span>")
+    # def _usage_formatter(view, context, model, name):
+    #     return round(model.current_usage_GB,3)
+
     def _usage_formatter(view, context, model, name):
-        return round(model.current_usage_GB,3)
+        u= round(model.current_usage_GB,3)
+        t=round(model.usage_limit_GB,3)
+        rate=round(u*100/t)
+        state= "danger" if u>=t else ('warning' if  rate>80 else 'success')
+        color= "#ff7e7e" if u>=t else ('#ffc107' if  rate>80 else '#9ee150')
+        return Markup(f"""
+        <div class="progress progress-lg position-relative" style="min-width: 100px;">
+          <div class="progress-bar progress-bar-striped" role="progressbar" style="width: {rate}%;background-color: {color};" aria-valuenow="{rate}" aria-valuemin="0" aria-valuemax="100"></div>
+              <span class='badge position-absolute' style="left:auto;right:auto;width: 100%;font-size:1em">{u} {_('user.home.usage.from')} {t} GB</span>
+
+        </div>
+        """)
+
+    def _expire_formatter(view, context, model, name):
+        days=(model.expiry_time-datetime.date.today()).days
+        
+        return Markup(f"<span class='badge ltr badge-{'success' if days>7 else ('warning' if days>0 else 'danger') }'>{days}</span> "+_('days'))
+
     column_formatters = {
         'name': _name_formatter,
         'UserLinks': _ul_formatter,
         'uuid': _uuid_formatter,
-        'current_usage_GB': _usage_formatter
+        'current_usage_GB': _usage_formatter,
+        "expiry_time":_expire_formatter
     }
     def on_model_delete(self, model):
         if len(User.query.all())<=1:
@@ -104,7 +137,8 @@ class UserAdmin(AdminLTEModelView):
         
     # def is_accessible(self):
     #     return g.is_admin
-
+    # def on_form_prefill(self, form, id):
+    #     form.expiry_time=form.expiry_time-datetime.date.today()
     def on_model_change(self, form, model, is_created):
         if len(User.query.all())%4==0:
             flash(('<div id="show-modal-donation"></div>'), ' d-none')
@@ -113,6 +147,7 @@ class UserAdmin(AdminLTEModelView):
         else:
             super().on_model_change(form, model, is_created)
         
+        # model.expiry_time=datetime.date.today()+datetime.timedelta(days=model.expiry_time)
         
         # if model.current_usage_GB < model.usage_limit_GB:
         #     xray_api.add_client(model.uuid)
