@@ -1,4 +1,4 @@
-from hiddifypanel.models import  User,Domain,DomainType,BoolConfig,StrConfig,ConfigEnum,hconfig
+from hiddifypanel.models import  *
 from hiddifypanel.panel.database import db
 
 
@@ -6,9 +6,7 @@ from hiddifypanel.panel.database import db
 from hiddifypanel.panel.database import db
 from dateutil import relativedelta
 import datetime
-from hiddifypanel.models import BoolConfig,StrConfig,ConfigEnum,hconfig,Proxy
-from hiddifypanel.models import Domain,DomainType
-from hiddifypanel.models import User
+from hiddifypanel.models import *
 from hiddifypanel.panel import hiddify
 import random
 import uuid
@@ -29,6 +27,7 @@ def _v1():
         external_ip=urllib.request.urlopen('https://v4.ident.me/').read().decode('utf8')
         
         data = [
+            Child(ip="self",id=0),
             StrConfig(key=ConfigEnum.db_version,value=1),
             User(name="default",usage_limit_GB=9000,expiry_time=next10year),
             Domain(domain=external_ip+".sslip.io",mode=DomainType.direct),
@@ -126,9 +125,66 @@ def _v8():
         "grpc direct trojan",
         "grpc direct vmess"])
     ])
+def _v9():
+    try:
+        column_type = User.mode.type.compile(db.engine.dialect)
+        db.engine.execute(f'ALTER TABLE user ADD COLUMN mode {column_type}')
+        column_type = User.comment.type.compile(db.engine.dialect)
+        db.engine.execute(f'ALTER TABLE user ADD COLUMN comment {column_type}')
+        column_type = Domain.alias.type.compile(db.engine.dialect)
+        db.engine.execute(f'ALTER TABLE domain ADD COLUMN alias {column_type}')
+        for u in User.query.all():
+            u.mode= UserMode.monthly if u.monthly else UserMode.no_reset
+    except:
+        pass
+    
+    db.session.bulk_save_objects(
+        [
+            BoolConfig(key=ConfigEnum.is_parent,value=False),
+            StrConfig(key=ConfigEnum.parent_panel,value=''),
+            StrConfig(key=ConfigEnum.unique_id,value=str(uuid.uuid4()))
+        ]
+    )
+
+def _v10():
+    all_configs=get_hconfigs()
+    try:
+        
+        db.engine.execute("ALTER TABLE `str_config` RENAME TO `str_config_old`")
+        db.engine.execute("ALTER TABLE `bool_config` RENAME TO `bool_config_old`")
+        
+    except:
+        pass
+    db.create_all()
+    
+    rows=[]
+    if not Child.query.filter(Child.id==0).first():
+        rows.append(Child(ip="self",id=0))
+    for c,v in all_configs.items():
+        if c.type()==bool:
+            rows.append(BoolConfig(key=c,value=v,child_id=0))
+        else:
+            rows.append(StrConfig(key=c,value=v,child_id=0))
+    
+    db.session.bulk_save_objects(rows)
+    
 
 def init_db():
+    # db.engine.execute(f'ALTER TABLE bool_config_old RENAME TO bool_config')
+    # db.engine.execute(f'ALTER TABLE str_config_old RENAME TO str_config')
+
     db.create_all()
+    
+    try:
+        column_type = Domain.child_id.type.compile(db.engine.dialect)
+        db.engine.execute(f'ALTER TABLE domain ADD COLUMN child_id {column_type}')
+        column_type = Proxy.child_id.type.compile(db.engine.dialect)
+        db.engine.execute(f'ALTER TABLE proxy ADD COLUMN child_id {column_type}')
+        column_type = BoolConfig.child_id.type.compile(db.engine.dialect)
+        db.engine.execute(f'ALTER TABLE bool_config ADD COLUMN child_id {column_type}')
+        column_type = StrConfig.child_id.type.compile(db.engine.dialect)
+        db.engine.execute(f'ALTER TABLE str_config ADD COLUMN child_id {column_type}')
+    except:pass
     try:
         db.engine.execute('ALTER TABLE user ADD COLUMN monthly BOOLEAN')
         db.engine.execute('ALTER TABLE user RENAME COLUMN monthly_usage_limit_GB TO usage_limit_GB')       
@@ -143,7 +199,7 @@ def init_db():
     db_version=int(hconfig(ConfigEnum.db_version) or 0) 
     print(f"Current DB version is {db_version}")
 
-    db_actions={1:_v1,2:_v2,3:_v3,6:_v6,8:_v8}
+    db_actions={1:_v1,2:_v2,3:_v3,6:_v6,8:_v8,9:_v9,10:_v10}
     for ver,db_action in db_actions.items():
         if ver<=db_version:continue
         print(f"Updating db from version {db_version}")
@@ -151,9 +207,10 @@ def init_db():
         db.session.commit()
         print(f"Updated successfuly db from version {db_version} to {ver}")
         db_version=ver
-        
+
     # 
-    StrConfig.query.filter(StrConfig.key == ConfigEnum.db_version).update({'value': db_version})
+    
+    StrConfig.query.filter(StrConfig.key == ConfigEnum.db_version and StrConfig.child_id==0).update({'value': db_version})
     db.session.commit()
     return BoolConfig.query.all()
 
